package com.capitalware.ufm.action.objects;

import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the MakeDir action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MakeDirObject extends UFMFileObject
{
   public String  targetDir = null;

   /**
    * The constructor
    */
   public MakeDirObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (targetDir != null)
         targetDir  = Tokens.replace(targetDir, paClass.actionProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (targetDir == null)
         throw new IllegalArgumentException("Error: You must specify a TargetDirectory for the MakeDir action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     Target Directory     = " + targetDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
         
      al.add("<"+CWConstants.MAKEDIR_ELEMENT+" "+CWConstants.DIR_ATTRIBUTE+"=\""+targetDir+"\" />"+LINE_SEPARATOR);
      
      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      s = CWConstants.MAKEDIR_ELEMENT+", "+labelName+", "+CWConstants.MAKEDIR_ELEMENT+", "+CWConstants.DIR_ATTRIBUTE+"="+targetDir+LINE_SEPARATOR;

      return s;
   }
}
