package com.capitalware.ufm.action.objects;

import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the Sleep action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class SleepObject extends UFMObject
{
   public int     milliseconds = 0;
   public int     seconds = 0;
   public int     minutes = 0;
   public int     hours = 0;

   /**
    * The constructor
    */
   public SleepObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if ( (milliseconds < 0) || (milliseconds > 59) )
         throw new IllegalArgumentException("Error: The milliseconds value is invalid. Use a number between 0 and 59.");

      if ( (seconds < 0) || (seconds > 59) )
         throw new IllegalArgumentException("Error: The seconds value is invalid. Use a number between 0 and 59.");
      
      if ( (minutes < 0) || (minutes > 59) )
         throw new IllegalArgumentException("Error: The minutes value is invalid. Use a number between 0 and 59.");

      if ( (hours < 0) || (hours > 23) )
         throw new IllegalArgumentException("Error: The hours value is invalid. Use a number between 0 and 23.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     Hours                = " + hours);
      UFM.logger.info("     Minutes              = " + minutes);
      UFM.logger.info("     Seconds              = " + seconds);
      UFM.logger.info("     MilliSeconds         = " + milliseconds);
   }

   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      String attributes = "";
      
      if (hours != 0)
         attributes += ""+CWConstants.HOURS_ATTRIBUTE+"=\"" + hours + "\" ";
      
      if (minutes != 0)
         attributes += ""+CWConstants.MINUTES_ATTRIBUTE+"=\"" + minutes + "\" ";
      
      if (seconds != 0)
         attributes += ""+CWConstants.SECONDS_ATTRIBUTE+"=\"" + seconds + "\" ";
      
      if (milliseconds != 0)
         attributes += ""+CWConstants.MILLISECONDS_ATTRIBUTE+"=\"" + milliseconds + "\" ";
      
      al.add("<"+CWConstants.SLEEP_ELEMENT+"" + attributes + "/>"+LINE_SEPARATOR);
      
      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      s = CWConstants.SLEEP_ELEMENT+", "+labelName+", "+CWConstants.SLEEP_ELEMENT+", ";
      
      if (hours != 0)
         s += CWConstants.HOURS_ATTRIBUTE+"="+hours+", ";
      
      if (minutes != 0)
         s += CWConstants.MINUTES_ATTRIBUTE+"="+minutes+", ";
      
      if (seconds != 0)
         s += CWConstants.SECONDS_ATTRIBUTE+"="+seconds+", ";
      
      if (milliseconds != 0)
         s += CWConstants.MILLISECONDS_ATTRIBUTE+"="+milliseconds+", ";

      s += LINE_SEPARATOR;
      
      return s;
   }
}
