package com.capitalware.ufm.action.objects;

import java.util.ArrayList;

import com.capitalware.ufm.mq.objects.MQObject;
import com.capitalware.ufm.mq.objects.QueueObject;
import com.capitalware.ufm.objects.CWConstants;

public abstract class UFMFileMQObject extends UFMFileObject
{
   public String           mqXMLFile   = null;
   public String           CCDTFile    = null;
   public String           qMgrName    = null;
   public String           userID      = null;
   public String           password    = null;
   public QueueObject      qObject     = null;
   public MQObject         mqo = null;
   
   public int              msgCount    = 0;

   /**
    * The constructor
    */
   public UFMFileMQObject()
   {
      super();
   }

   /**
    * Build XML tags from MQ values.
    * @return
    */
   public ArrayList<String> createMQTag()
   {
      ArrayList<String> al = new ArrayList<String>();
      
      if ((mqXMLFile != null) || (CCDTFile != null) || (qMgrName != null) || (qObject != null) )
      {   
         al.add("  <"+CWConstants.MQ_ELEMENT+">"+LINE_SEPARATOR);
   
         if (mqXMLFile != null)
            al.add("    <"+CWConstants.MQFILE_ELEMENT+">"+mqXMLFile+"</"+CWConstants.MQFILE_ELEMENT+">"+LINE_SEPARATOR);
         
         if (CCDTFile != null)
            al.add("    <"+CWConstants.CCDTFILE_ELEMENT+">"+CCDTFile+"</"+CWConstants.CCDTFILE_ELEMENT+">"+LINE_SEPARATOR);
         
         if (qMgrName != null)
            al.add("    <"+CWConstants.QMGRNAME_ELEMENT+">"+qMgrName+"</"+CWConstants.QMGRNAME_ELEMENT+">"+LINE_SEPARATOR);
         
         if (qObject != null)
         {
            if (qObject.qName != null)
            {
               if (qObject.qMgrName != null)
                  al.add("    <"+CWConstants.QUEUENAME_ELEMENT+" "+CWConstants.QMGRNAME_ATTRIBUTE+"=\""+qObject.qMgrName+"\">"+qObject.qName+"</"+CWConstants.QUEUENAME_ELEMENT+">"+LINE_SEPARATOR);
               else
                  al.add("    <"+CWConstants.QUEUENAME_ELEMENT+">"+qObject.qName+"</"+CWConstants.QUEUENAME_ELEMENT+">"+LINE_SEPARATOR);
            }
         }
         
         al.add("  </"+CWConstants.MQ_ELEMENT+">"+LINE_SEPARATOR);
      }
      
      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String createMQTagForStatusUpdate()
   {
      StringBuffer sb = new StringBuffer();
      
      if (mqXMLFile != null)
         sb.append(CWConstants.MQFILE_ELEMENT+"="+mqXMLFile+", ");
      
      if (CCDTFile != null)
         sb.append(CWConstants.CCDTFILE_ELEMENT+"="+CCDTFile+", ");
      
      if (mqo.qMgrName != null)
         sb.append(CWConstants.QMGRNAME_ELEMENT+"="+mqo.qMgrName+", ");
      
      if (mqo.qObject != null)
      {
         if (mqo.qObject.qName != null)
         {
               sb.append(CWConstants.QUEUENAME_ELEMENT+"="+mqo.qObject.qName+", ");
         }
      }
      
      return sb.toString();
   }
   
   /**
    * Build XML tags from Remote values.
    * @param remoteQMgrName
    * @return
    */
   public ArrayList<String> createRemoteTag(String remotejobXmlFile, String remoteDirectory, String remoteFilename)
   {
      ArrayList<String> al = new ArrayList<String>();
      
      if ((remotejobXmlFile != null) || (remoteDirectory != null) || (remoteFilename != null) )
      {   
         al.add("  <"+CWConstants.REMOTE_ELEMENT+">"+LINE_SEPARATOR);
   
         if (remotejobXmlFile != null)
            al.add("    <"+CWConstants.EXECUTE_ELEMENT+">"+remotejobXmlFile+"</"+CWConstants.EXECUTE_ELEMENT+">"+LINE_SEPARATOR);
         
         if (remoteDirectory != null)
            al.add("    <"+CWConstants.DIRECTORY_ELEMENT+">"+remoteDirectory+"</"+CWConstants.DIRECTORY_ELEMENT+">"+LINE_SEPARATOR);
         
         if (remoteFilename != null)
            al.add("    <"+CWConstants.FILENAME_ELEMENT+">"+remoteFilename+"</"+CWConstants.FILENAME_ELEMENT+">"+LINE_SEPARATOR);
         
         al.add("  </"+CWConstants.REMOTE_ELEMENT+">"+LINE_SEPARATOR);
      }
      
      return al;
   }
}
