package com.capitalware.ufm.actions;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.DeleteObject;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.objects.UFMException;

/**
 * This class will handle the delete action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class DeleteAction extends UFMAction
{
   private DeleteObject   ddo;

   /**
    * The constructor
    * @param ddo
    */
   public DeleteAction(DeleteObject ddo)
   {
      super(ddo.actionName);
      this.ddo = ddo;
   }

   /**
    * Perform the delete work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      ddo.printValues();

      try
      {
         ddo.filenames = IO.buildStringArrayOfFiles(ddo.filenames);
         
         for (int i=0; (i < ddo.filenames.length) && (exitCode == 0); i++)
         {
            try
            {
               IO.deleteFile(ddo.filenames[i]);
               ddo.paClass.handleDeletedWatchFoundFile();
               ddo.fileCount++;
            }
            catch (UFMException e)
            {
               UFM.handleOnError(ddo.paClass.actionProperties, null);
               UFM.logger.fatal("UFMException: "+e.getLocalizedMessage());
               if (e.getCause() != null)
                  UFM.logger.fatal(e.getCause().toString());
               if (ddo.onErrorFail)
                  exitCode = 8;
            }
         }
      }
      catch (UFMException e)
      {
         UFM.logger.fatal("UFMException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      finally
      {
         if (!ddo.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
