package com.capitalware.ufm.actions;

import java.util.ArrayList;
import java.util.Hashtable;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.handlers.ProcessActions;
import com.capitalware.ufm.action.objects.UFMObject;
import com.capitalware.ufm.action.objects.LoopObject;
import com.capitalware.ufm.handlers.InternalMessageQueue;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class will handle the loop action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class LoopAction extends UFMAction
{
   private LoopObject         lo = null;
   private InternalMessageQueue       iq = null;

   /**
    * The constructor
    * @param lo
    * @param iq
    */
   public LoopAction(LoopObject lo, InternalMessageQueue iq)
   {
      super(lo.actionName);
      this.lo = lo;
      this.iq = iq;
   }

   /**
    * Perform the loop work.
    * @return exitCode
    */
   public int doWork()
   {
      int      exitCode = 0, currentExitCode = 0, i = 0;
      lo.printValues();
      
      if (lo.actionAL != null)
      {
         i=lo.start;
         while ( ((lo.by > 0) && (i <= lo.end)) ||  // ascending
                 ((lo.by < 0) && (i >= lo.end)) )   // descending
         {
            UFM.logger.info(" ");
            UFM.logger.info("---------- Loop index="+i+" ----------");

            /* Clone the array of objects */
            ArrayList<UFMObject> newActionAL = new ArrayList<UFMObject>();
            
            Hashtable<String,String> actionProperties = (Hashtable<String,String>) lo.paClass.actionProperties.clone();
            actionProperties.put(CWConstants.LOOP_COUNTER, i+"");
            
            for (int k=0; k < lo.actionAL.size(); k++)
               newActionAL.add((UFMObject)lo.actionAL.get(k).clone());
            
            // clone the arraylist of Actions so that we do not alter the original values
            ProcessActions pa = new ProcessActions(iq);
            currentExitCode = pa.doWork(newActionAL, actionProperties);
            if (currentExitCode > exitCode)
               exitCode = currentExitCode;
            
            i += lo.by;
         }
         
         UFM.logger.info(" ");
         UFM.logger.info("---------- Loop done. ----------");
      }
      else
      {
         UFM.logger.warn("Loop does not have any Actions.");
      }

      if (!lo.onErrorFail)
         exitCode = 0; /* reset back to zero */
      
      return exitCode;
   }
}
