package com.capitalware.ufm.actions;

import java.io.IOException;

import org.jdom.JDOMException;

import com.ibm.mq.MQException;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.MQPutQuitObject;
import com.capitalware.ufm.mq.MQPutQuit;
import com.capitalware.ufm.mq.objects.MQObject;
import com.capitalware.ufm.objects.UFMException;
import com.capitalware.ufm.xml.MQXml;

/**
 * This class will handle the move action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MQPutQuitAction extends UFMAction
{
   private MQPutQuitObject   pqo;

   /**
    * The constructor
    * @param pqo
    */
   public MQPutQuitAction(MQPutQuitObject pqo)
   {
      super(pqo.actionName);
      this.pqo = pqo;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      pqo.printValues();
      MQPutQuit mqh = null;

      try
      {
         if (pqo.mqXMLFile != null)
         {
            MQXml mqX = new MQXml(pqo.qMgrName, pqo.qObject, pqo.CCDTFile);
            mqX.readXMLFile(pqo.mqXMLFile);
            pqo.mqo = mqX.getMQObject();
         }
         else
         {
            pqo.mqo = new MQObject(pqo.qMgrName, pqo.qObject, pqo.CCDTFile);
         }

         pqo.mqo.checkQM();
         pqo.mqo.dumpUserParms();

         mqh = new MQPutQuit(pqo.mqo);

         mqh.connect();

         mqh.simplePut1(pqo);
         pqo.msgCount++;
      }
      catch (JDOMException e)
      {
         UFM.logger.fatal("JDOMException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (MQException e)
      {
         UFM.logger.fatal("MQException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal("MQException: " + e.getCause());
         UFM.logger.fatal("MQCC=" + e.completionCode + " : MQRC="+e.reasonCode);
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (UFMException e)
      {
         UFM.logger.fatal("UFMException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      catch (Exception e)
      {
         UFM.logger.fatal("Exception: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      finally
      {
         if ( mqh != null)
            mqh.disconnect();

         if (!pqo.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
