package com.capitalware.ufm.actions;

import java.io.File;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.RenameObject;
import com.capitalware.ufm.handlers.Tokens;

/**
 * This class will handle the rename action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class RenameAction extends UFMAction
{
   private RenameObject   ro;

   /**
    * The constructor
    * @param ro
    */
   public RenameAction(RenameObject ro)
   {
      super(ro.actionName);
      this.ro = ro;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      String toPathAndFilename = ro.toFile;
      ro.printValues();

      // File (or directory) with old name
      File file = new File(ro.srcFilename);

      toPathAndFilename = Tokens.replace(ro.actionName, toPathAndFilename, ro.srcFilename, 1, ro.paClass.actionProperties);

      // File (or directory) with new name
      File file2 = new File(toPathAndFilename);

      // Rename file (or directory)
      if (file.renameTo(file2))
      {
         ro.fileCount++;
         UFM.logger.info("Successfully renamed file: "+ro.srcFilename+ " to " + toPathAndFilename);
      }         
      else
      {
         UFM.logger.fatal("Cannot rename file: " + ro.srcFilename);
         exitCode = 8;
      }
      
      if (!ro.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }
}
