package com.capitalware.ufm.objects;

import java.util.ArrayList;

import com.capitalware.ufm.UFM;

/**
 * This class holds the connection information.
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.0
 * @license Apache 2 License
 */
public class ConnectionObject
{
   protected static final String LINE_SEPARATOR = System.getProperty("line.separator");
   
   public String    hostname     = null;
   public int       port         = -1;   /* ftp uses 21, sftp and scp use 22 */
   public String    userID       = null;
   public String    password     = null;

   /**
    * The constructor
    */
   public ConnectionObject()
   {
      super();
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject(String name)
   {
      if (hostname == null)
         throw new IllegalArgumentException("Error: The "+name.toUpperCase()+" host name cannot be blank.");
      
      if (userID == null)
         throw new IllegalArgumentException("Error: The "+name.toUpperCase()+" UserID cannot be blank.");
  
      if (password == null)
         throw new IllegalArgumentException("Error: The "+name.toUpperCase()+" Password cannot be blank.");
   }

   /**
    * Output the info
    */
   public void printValues(String name)
   {
      UFM.logger.info("Values used for "+name.toUpperCase()+" connection:");
      UFM.logger.info("     Hostname             = " + hostname);
      UFM.logger.info("     Port                 = " + port);
      UFM.logger.info("     UserID               = " + userID);
      UFM.logger.info("     Password Length      = " + (password == null ? password:password.length()));
   }

   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      al.add("<"+CWConstants.HOSTNAME_ELEMENT+">"+hostname+"</"+CWConstants.HOSTNAME_ELEMENT+">"+LINE_SEPARATOR);
      al.add("<"+CWConstants.PORT_ELEMENT+">"+port+"</"+CWConstants.PORT_ELEMENT+">"+LINE_SEPARATOR);
      al.add("<"+CWConstants.USERID_ELEMENT+">"+userID+"</"+CWConstants.USERID_ELEMENT+">"+LINE_SEPARATOR);
      al.add("<"+CWConstants.PASSWORD_ELEMENT+">"+password+"</"+CWConstants.PASSWORD_ELEMENT+">"+LINE_SEPARATOR);

      return al;
   }
}
